@@ -1,6 +1,6 @@
 package YATT::Util::redundant_sprintf;
 use strict;
-use warnings FATAL => qw/all/;
+use warnings qw(FATAL all NONFATAL misc);
 
 sub import {
   warnings->unimport(qw/redundant/) if $] >= 5.021002;
