@@ -4,8 +4,8 @@ package YATT;
 require 5.007_001; # For sprintf reordering.
 
 use strict;
-use warnings FATAL => qw(all);
-our $VERSION = '0.0_9';
+use warnings qw(FATAL all NONFATAL misc);
+our $VERSION = '0.0.10';
 use File::Basename;
 
 BEGIN {
