@@ -1,7 +1,7 @@
 # -*- mode: perl; coding: utf-8 -*-
 package YATT::LRXML::MetaInfo;
 use strict;
-use warnings FATAL => qw(all);
+use warnings qw(FATAL all NONFATAL misc);
 use base qw(YATT::Class::Configurable);
 BEGIN {require Exporter; *import = \&Exporter::import}
 our @EXPORT = qw(MetaInfo);
