@@ -1,7 +1,7 @@
 # -*- mode: perl; coding: utf-8 -*-
 package YATT::Toplevel::CGI;
 use strict;
-use warnings FATAL => qw(all);
+use warnings qw(FATAL all NONFATAL misc);
 
 BEGIN {
   require Exporter; *import = \&Exporter::import;
@@ -536,6 +536,12 @@ sub new_cgi {
     require YATT::Util::CGICompat;
     import YATT::Util::CGICompat;
   }
+  if ($class eq "CGI::Simple" and not $class->can("multi_param")) {
+    *{globref($class, "multi_param")} = $class->can("param");
+  }
+  unless ($class->can("multi_param")) {
+    croak "cgi class($class) doesn't have multi_param method!";
+  }
 
   # 1. To make sure passing 'public' parameters only.
   # 2. To avoid CGI::Simple eval()
