@@ -1,6 +1,6 @@
 package YATT::Util::SymbolHash;
 use strict;
-use warnings FATAL => qw(all);
+use warnings qw(FATAL all NONFATAL misc);
 
 use Exporter qw(import);
 our @EXPORT = qw(rebless_hash_with);
