@@ -1,6 +1,6 @@
 package YATT::Util::VarExporter;
 use strict;
-use warnings FATAL => qw(all);
+use warnings qw(FATAL all NONFATAL misc);
 
 use base qw(YATT::Class::Configurable);
 use YATT::Fields qw(pages);
